@@ -4,7 +4,6 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"os"
 	"path"
 	"regexp"
 	"sort"
@@ -28,37 +27,6 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
-const (
-	defaultLength     = 24
-	defaultXKCDLength = 4
-)
-
-// defaultLengthFromEnv will determine the password length from the env variable
-// GOPASS_PW_DEFAULT_LENGTH or fallback to the hard-coded default length.
-// If the env variable is set by the user and is valid, the boolean return value
-// will be true, otherwise it will be false.
-func defaultLengthFromEnv(ctx context.Context) (int, bool) {
-	def := defaultLength
-
-	if l := config.Int(ctx, "generate.length"); l > 0 {
-		def = l
-	}
-
-	lengthStr, isSet := os.LookupEnv("GOPASS_PW_DEFAULT_LENGTH")
-	if !isSet {
-		return def, false
-	}
-	length, err := strconv.Atoi(lengthStr)
-	if err != nil {
-		return def, false
-	}
-	if length < 1 {
-		return def, false
-	}
-
-	return length, true
-}
-
 var reNumber = regexp.MustCompile(`^\d+$`)
 
 // Generate and save a password.
@@ -239,7 +207,7 @@ func (s *Action) generatePassword(ctx context.Context, c *cli.Context, length, n
 
 	switch generator {
 	case "memorable":
-		if c.Bool("strict") {
+		if isStrict(ctx, c) {
 			return pwgen.GenerateMemorablePassword(pwlen, symbols, true), nil
 		}
 
@@ -247,7 +215,7 @@ func (s *Action) generatePassword(ctx context.Context, c *cli.Context, length, n
 	case "external":
 		return pwgen.GenerateExternal(pwlen)
 	default:
-		if c.Bool("strict") {
+		if isStrict(ctx, c) {
 			return pwgen.GeneratePasswordWithAllClasses(pwlen, symbols)
 		}
 
@@ -262,7 +230,7 @@ func (s *Action) generatePassword(ctx context.Context, c *cli.Context, length, n
 // again.
 func getPwLengthFromEnvOrAskUser(ctx context.Context) (int, error) {
 	var pwlen int
-	candidateLength, isCustom := defaultLengthFromEnv(ctx)
+	candidateLength, isCustom := config.DefaultPasswordLengthFromEnv(ctx)
 	if !isCustom {
 		question := "How long should the password be?"
 		iv, err := termio.AskForInt(ctx, question, candidateLength)
@@ -317,33 +285,41 @@ func (s *Action) generatePasswordForRule(ctx context.Context, c *cli.Context, le
 // generatePasswordXKCD walks through the steps necessary to create an XKCD-style
 // password.
 func (s *Action) generatePasswordXKCD(ctx context.Context, c *cli.Context, length string) (string, error) {
-	xkcdSeparator := " "
+	sep := config.String(c.Context, "pwgen.xkcd.sep")
 	if c.IsSet("sep") {
-		xkcdSeparator = c.String("sep")
+		sep = c.String("sep")
+	}
+	lang := config.String(c.Context, "pwgen.xkcd.lang")
+	if c.IsSet("lang") {
+		lang = c.String("lang")
 	}
 
-	var pwlen int
-	if length == "" {
-		candidateLength := defaultXKCDLength
-		question := "How many words should be combined to a password?"
-		iv, err := termio.AskForInt(ctx, question, candidateLength)
-		if err != nil {
-			return "", exit.Error(exit.Usage, err, "password length must be a number")
-		}
-		pwlen = iv
-	} else {
+	pwlen := config.Int(c.Context, "pwgen.xkcd.len")
+	switch {
+	case length != "":
+		// using the command line supplied value
 		iv, err := strconv.Atoi(length)
 		if err != nil {
 			return "", exit.Error(exit.Usage, err, "password length must be a number: %s", err)
 		}
 		pwlen = iv
+	case pwlen < 1:
+		// no config value, nothing on the command line: ask the user
+		question := "How many words should be combined to a password?"
+		iv, err := termio.AskForInt(ctx, question, config.DefaultXKCDLength)
+		if err != nil {
+			return "", exit.Error(exit.Usage, err, "password length must be a number")
+		}
+		pwlen = iv
+	default:
+		// no-op, using the config value
 	}
 
 	if pwlen < 1 {
 		return "", exit.Error(exit.Usage, nil, "password length must not be zero")
 	}
 
-	return xkcdgen.RandomLengthDelim(pwlen, xkcdSeparator, c.String("lang"))
+	return xkcdgen.RandomLengthDelim(pwlen, sep, lang)
 }
 
 // generateSetPassword will update or create a secret.
@@ -524,3 +500,17 @@ func filterPrefix(in []string, prefix string) []string {
 
 	return out
 }
+
+func isStrict(ctx context.Context, c *cli.Context) bool {
+	cfg := config.FromContext(ctx)
+
+	if c.Bool("strict") {
+		return true
+	}
+
+	if cfg.IsSet("generate.strict") {
+		return cfg.GetBool("generate.strict")
+	}
+
+	return false
+}
