@@ -36,6 +36,10 @@ func TestConfig(t *testing.T) {
 	assert.Equal(t, true, Bool(ctx, "core.bool"))
 	assert.Equal(t, "foo", String(ctx, "core.string"))
 	assert.Equal(t, 42, Int(ctx, "core.int"))
+
+	assert.NoError(t, cfg.SetEnv("generate.length", "16"))
+	actual_length, _ := DefaultPasswordLengthFromEnv(ctx)
+	assert.Equal(t, 16, actual_length)
 }
 
 func TestEnvConfig(t *testing.T) {
